# nb-thumb

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

<div>

[![](https://github.com/fastai/nb-thumb/actions/workflows/test.yaml/badge.svg)](https://github.com/fastai/nb-thumb/actions/workflows/test.yaml)

</div>

## Install

``` sh
pip install nb_thumb
```

## Quickstart

``` python
from nb_thumb.thumb import nb2thumb
```

``` python
nb2thumb(nb_path='_test_nbs/geom_col.ipynb', 
         label='two_variable_bar_plot',
         size=(200,200))
```

![](index_files/figure-commonmark/cell-3-output-1.png)

## Usage

See [this page](https://fastai.github.io/nb-thumb/thumb.html).
